@@ -25,7 +25,6 @@
 #include <glib/gi18n.h>
 #include <gio/gio.h>
 #include <gdk/gdk.h>
-#include <gtk/gtk.h>
 
 #include "settings.h"
 #include "utils.h"
@@ -57,7 +56,6 @@ settings_bundle_free (SettingsBundle *bundle)
   g_free (bundle);
 }
 
-// static GVariant *get_gtk_theme (gpointer data);
 static GVariant *get_color_scheme (gpointer data);
 static GVariant *get_high_contrast (gpointer data);
 
@@ -286,8 +284,6 @@ init_settings_table (XdpImplSettings *settings,
         g_signal_connect (setting, "changed", G_CALLBACK(on_settings_changed), settings);
         g_hash_table_insert (settings_table, (gpointer) setting_defs[i].gs_schema_id, bundle);
     }
-
-    g_settings_schema_source_unref (source);
 }
 
 gboolean
